==> ratis-proto-2.5.0-sources.jar: org/apache/ratis/test/proto/GreeterGrpc.java <==
package org.apache.ratis.test.proto;

import static org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.51.1)",
    comments = "Source: Test.proto")
@org.apache.ratis.thirdparty.io.grpc.stub.annotations.GrpcGenerated
public final class GreeterGrpc {

  private GreeterGrpc() {}

  public static final String SERVICE_NAME = "org.apache.ratis.test.Greeter";

  // Static method descriptors that strictly reflect the proto.
  private static volatile org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.test.proto.HelloRequest,
      org.apache.ratis.test.proto.HelloReply> getHelloMethod;

  @org.apache.ratis.thirdparty.io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Hello",
      requestType = org.apache.ratis.test.proto.HelloRequest.class,
      responseType = org.apache.ratis.test.proto.HelloReply.class,
      methodType = org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.test.proto.HelloRequest,
      org.apache.ratis.test.proto.HelloReply> getHelloMethod() {
    org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.test.proto.HelloRequest, org.apache.ratis.test.proto.HelloReply> getHelloMethod;
    if ((getHelloMethod = GreeterGrpc.getHelloMethod) == null) {
      synchronized (GreeterGrpc.class) {
        if ((getHelloMethod = GreeterGrpc.getHelloMethod) == null) {
          GreeterGrpc.getHelloMethod = getHelloMethod =
              org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.<org.apache.ratis.test.proto.HelloRequest, org.apache.ratis.test.proto.HelloReply>newBuilder()
              .setType(org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Hello"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.ratis.test.proto.HelloRequest.getDefaultInstance()))
              .setResponseMarshaller(org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.ratis.test.proto.HelloReply.getDefaultInstance()))
              .setSchemaDescriptor(new GreeterMethodDescriptorSupplier("Hello"))
              .build();
        }
      }
    }
    return getHelloMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static GreeterStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterStub>() {
        @java.lang.Override
        public GreeterStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new GreeterStub(channel, callOptions);
        }
      };
    return GreeterStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static GreeterBlockingStub newBlockingStub(
      org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterBlockingStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterBlockingStub>() {
        @java.lang.Override
        public GreeterBlockingStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new GreeterBlockingStub(channel, callOptions);
        }
      };
    return GreeterBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static GreeterFutureStub newFutureStub(
      org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterFutureStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterFutureStub>() {
        @java.lang.Override
        public GreeterFutureStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new GreeterFutureStub(channel, callOptions);
        }
      };
    return GreeterFutureStub.newStub(factory, channel);
  }

  /**
   */
  public static abstract class GreeterImplBase implements org.apache.ratis.thirdparty.io.grpc.BindableService {

    /**
     */
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.test.proto.HelloRequest> hello(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.test.proto.HelloReply> responseObserver) {
      return org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall(getHelloMethod(), responseObserver);
    }

    @java.lang.Override public final org.apache.ratis.thirdparty.io.grpc.ServerServiceDefinition bindService() {
      return org.apache.ratis.thirdparty.io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getHelloMethod(),
            org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncBidiStreamingCall(
              new MethodHandlers<
                org.apache.ratis.test.proto.HelloRequest,
                org.apache.ratis.test.proto.HelloReply>(
                  this, METHODID_HELLO)))
          .build();
    }
  }

  /**
   */
  public static final class GreeterStub extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractAsyncStub<GreeterStub> {
    private GreeterStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GreeterStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new GreeterStub(channel, callOptions);
    }

    /**
     */
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.test.proto.HelloRequest> hello(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.test.proto.HelloReply> responseObserver) {
      return org.apache.ratis.thirdparty.io.grpc.stub.ClientCalls.asyncBidiStreamingCall(
          getChannel().newCall(getHelloMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   */
  public static final class GreeterBlockingStub extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractBlockingStub<GreeterBlockingStub> {
    private GreeterBlockingStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GreeterBlockingStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new GreeterBlockingStub(channel, callOptions);
    }
  }

  /**
   */
  public static final class GreeterFutureStub extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractFutureStub<GreeterFutureStub> {
    private GreeterFutureStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GreeterFutureStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new GreeterFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_HELLO = 0;

  private static final class MethodHandlers<Req, Resp> implements
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final GreeterImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(GreeterImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Req> invoke(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_HELLO:
          return (org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Req>) serviceImpl.hello(
              (org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.test.proto.HelloReply>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class GreeterBaseDescriptorSupplier
      implements org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoFileDescriptorSupplier, org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    GreeterBaseDescriptorSupplier() {}

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.apache.ratis.test.proto.TestProto.getDescriptor();
    }

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("Greeter");
    }
  }

  private static final class GreeterFileDescriptorSupplier
      extends GreeterBaseDescriptorSupplier {
    GreeterFileDescriptorSupplier() {}
  }

  private static final class GreeterMethodDescriptorSupplier
      extends GreeterBaseDescriptorSupplier
      implements org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    GreeterMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor serviceDescriptor;

  public static org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor getServiceDescriptor() {
    org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (GreeterGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new GreeterFileDescriptorSupplier())
              .addMethod(getHelloMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> ratis-proto-3.0.0-sources.jar: org/apache/ratis/test/proto/GreeterGrpc.java <==
package org.apache.ratis.test.proto;

import static org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.generateFullMethodName;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.58.0)",
    comments = "Source: Test.proto")
@org.apache.ratis.thirdparty.io.grpc.stub.annotations.GrpcGenerated
public final class GreeterGrpc {

  private GreeterGrpc() {}

  public static final java.lang.String SERVICE_NAME = "org.apache.ratis.test.Greeter";

  // Static method descriptors that strictly reflect the proto.
  private static volatile org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.test.proto.HelloRequest,
      org.apache.ratis.test.proto.HelloReply> getHelloMethod;

  @org.apache.ratis.thirdparty.io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Hello",
      requestType = org.apache.ratis.test.proto.HelloRequest.class,
      responseType = org.apache.ratis.test.proto.HelloReply.class,
      methodType = org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
  public static org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.test.proto.HelloRequest,
      org.apache.ratis.test.proto.HelloReply> getHelloMethod() {
    org.apache.ratis.thirdparty.io.grpc.MethodDescriptor<org.apache.ratis.test.proto.HelloRequest, org.apache.ratis.test.proto.HelloReply> getHelloMethod;
    if ((getHelloMethod = GreeterGrpc.getHelloMethod) == null) {
      synchronized (GreeterGrpc.class) {
        if ((getHelloMethod = GreeterGrpc.getHelloMethod) == null) {
          GreeterGrpc.getHelloMethod = getHelloMethod =
              org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.<org.apache.ratis.test.proto.HelloRequest, org.apache.ratis.test.proto.HelloReply>newBuilder()
              .setType(org.apache.ratis.thirdparty.io.grpc.MethodDescriptor.MethodType.BIDI_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "Hello"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.ratis.test.proto.HelloRequest.getDefaultInstance()))
              .setResponseMarshaller(org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoUtils.marshaller(
                  org.apache.ratis.test.proto.HelloReply.getDefaultInstance()))
              .setSchemaDescriptor(new GreeterMethodDescriptorSupplier("Hello"))
              .build();
        }
      }
    }
    return getHelloMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static GreeterStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterStub>() {
        @java.lang.Override
        public GreeterStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new GreeterStub(channel, callOptions);
        }
      };
    return GreeterStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static GreeterBlockingStub newBlockingStub(
      org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterBlockingStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterBlockingStub>() {
        @java.lang.Override
        public GreeterBlockingStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new GreeterBlockingStub(channel, callOptions);
        }
      };
    return GreeterBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static GreeterFutureStub newFutureStub(
      org.apache.ratis.thirdparty.io.grpc.Channel channel) {
    org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterFutureStub> factory =
      new org.apache.ratis.thirdparty.io.grpc.stub.AbstractStub.StubFactory<GreeterFutureStub>() {
        @java.lang.Override
        public GreeterFutureStub newStub(org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
          return new GreeterFutureStub(channel, callOptions);
        }
      };
    return GreeterFutureStub.newStub(factory, channel);
  }

  /**
   */
  public interface AsyncService {

    /**
     */
    default org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.test.proto.HelloRequest> hello(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.test.proto.HelloReply> responseObserver) {
      return org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall(getHelloMethod(), responseObserver);
    }
  }

  /**
   * Base class for the server implementation of the service Greeter.
   */
  public static abstract class GreeterImplBase
      implements org.apache.ratis.thirdparty.io.grpc.BindableService, AsyncService {

    @java.lang.Override public final org.apache.ratis.thirdparty.io.grpc.ServerServiceDefinition bindService() {
      return GreeterGrpc.bindService(this);
    }
  }

  /**
   * A stub to allow clients to do asynchronous rpc calls to service Greeter.
   */
  public static final class GreeterStub
      extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractAsyncStub<GreeterStub> {
    private GreeterStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GreeterStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new GreeterStub(channel, callOptions);
    }

    /**
     */
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.test.proto.HelloRequest> hello(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.test.proto.HelloReply> responseObserver) {
      return org.apache.ratis.thirdparty.io.grpc.stub.ClientCalls.asyncBidiStreamingCall(
          getChannel().newCall(getHelloMethod(), getCallOptions()), responseObserver);
    }
  }

  /**
   * A stub to allow clients to do synchronous rpc calls to service Greeter.
   */
  public static final class GreeterBlockingStub
      extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractBlockingStub<GreeterBlockingStub> {
    private GreeterBlockingStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GreeterBlockingStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new GreeterBlockingStub(channel, callOptions);
    }
  }

  /**
   * A stub to allow clients to do ListenableFuture-style rpc calls to service Greeter.
   */
  public static final class GreeterFutureStub
      extends org.apache.ratis.thirdparty.io.grpc.stub.AbstractFutureStub<GreeterFutureStub> {
    private GreeterFutureStub(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected GreeterFutureStub build(
        org.apache.ratis.thirdparty.io.grpc.Channel channel, org.apache.ratis.thirdparty.io.grpc.CallOptions callOptions) {
      return new GreeterFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_HELLO = 0;

  private static final class MethodHandlers<Req, Resp> implements
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final AsyncService serviceImpl;
    private final int methodId;

    MethodHandlers(AsyncService serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Req> invoke(
        org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_HELLO:
          return (org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<Req>) serviceImpl.hello(
              (org.apache.ratis.thirdparty.io.grpc.stub.StreamObserver<org.apache.ratis.test.proto.HelloReply>) responseObserver);
        default:
          throw new AssertionError();
      }
    }
  }

  public static final org.apache.ratis.thirdparty.io.grpc.ServerServiceDefinition bindService(AsyncService service) {
    return org.apache.ratis.thirdparty.io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
        .addMethod(
          getHelloMethod(),
          org.apache.ratis.thirdparty.io.grpc.stub.ServerCalls.asyncBidiStreamingCall(
            new MethodHandlers<
              org.apache.ratis.test.proto.HelloRequest,
              org.apache.ratis.test.proto.HelloReply>(
                service, METHODID_HELLO)))
        .build();
  }

  private static abstract class GreeterBaseDescriptorSupplier
      implements org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoFileDescriptorSupplier, org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    GreeterBaseDescriptorSupplier() {}

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return org.apache.ratis.test.proto.TestProto.getDescriptor();
    }

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("Greeter");
    }
  }

  private static final class GreeterFileDescriptorSupplier
      extends GreeterBaseDescriptorSupplier {
    GreeterFileDescriptorSupplier() {}
  }

  private static final class GreeterMethodDescriptorSupplier
      extends GreeterBaseDescriptorSupplier
      implements org.apache.ratis.thirdparty.io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final java.lang.String methodName;

    GreeterMethodDescriptorSupplier(java.lang.String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public org.apache.ratis.thirdparty.com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor serviceDescriptor;

  public static org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor getServiceDescriptor() {
    org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (GreeterGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = org.apache.ratis.thirdparty.io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new GreeterFileDescriptorSupplier())
              .addMethod(getHelloMethod())
              .build();
        }
      }
    }
    return result;
  }
}
